==> react-settings-form-0.3.22.tgz: package/esm/SettingsForm.js <==
import React, { useMemo } from 'react';
import { createForm } from '@formily/core';
import { Form } from '@formily/antd';
import { observer } from '@formily/react';
import { requestIdle, cancelIdle } from '@designable/shared';
import { usePrefix, useSelected, useCurrentNode, IconWidget, } from '@designable/react';
import { SchemaField } from './SchemaField';
import { SettingsFormContext } from './shared/context';
import { useLocales } from './effects';
import { NodePath } from './components/NodePath';
import { Empty } from 'antd';
import cls from 'classnames';
import './styles.less';
var GlobalState = {
    idleRequest: null,
};
export var SettingsForm = observer(function (props) {
    var _a, _b;
    var node = useCurrentNode();
    var selected = useSelected();
    var prefix = usePrefix('settings-form');
    var form = useMemo(function () {
        return createForm({
            values: node === null || node === void 0 ? void 0 : node.props,
            effects: function () {
                useLocales();
            },
        });
    }, [node, (_a = node === null || node === void 0 ? void 0 : node.designerProps) === null || _a === void 0 ? void 0 : _a.propsSchema]);
    var isEmpty = !(node && ((_b = node.designerProps) === null || _b === void 0 ? void 0 : _b.propsSchema) &&
        selected.length === 1);
    var render = function () {
        if (!isEmpty) {
            return (React.createElement("div", { className: cls(prefix, props.className), style: props.style, key: node.id },
                React.createElement(SettingsFormContext.Provider, { value: props },
                    React.createElement(Form, { form: form, colon: false, labelWidth: 120, labelAlign: "left", wrapperAlign: "right", feedbackLayout: "none", tooltipLayout: "text" },
                        React.createElement(SchemaField, { schema: node.designerProps.propsSchema, components: props.components })))));
        }
        return (React.createElement("div", { className: prefix + '-empty' },
            React.createElement(Empty, null)));
    };
    return (React.createElement(IconWidget.Provider, { tooltip: true },
        React.createElement("div", { className: prefix + '-wrapper' },
            !isEmpty && React.createElement(NodePath, null),
            React.createElement("div", { className: prefix + '-content' }, render()))));
}, {
    scheduler: function (update) {
        cancelIdle(GlobalState.idleRequest);
        GlobalState.idleRequest = requestIdle(update);
    },
});

==> react-settings-form-0.4.17.tgz: package/esm/SettingsForm.js <==
import React, { useMemo } from 'react';
import { createForm } from '@formily/core';
import { Form } from '@formily/antd';
import { observer } from '@formily/react';
import { requestIdle, cancelIdle } from '@designable/shared';
import { usePrefix, useSelected, useOperation, useCurrentNode, IconWidget, } from '@designable/react';
import { SchemaField } from './SchemaField';
import { SettingsFormContext } from './shared/context';
import { useLocales, useSnapshot } from './effects';
import { NodePath } from './components/NodePath';
import { Empty } from 'antd';
import cls from 'classnames';
import './styles.less';
var GlobalState = {
    idleRequest: null,
};
export var SettingsForm = observer(function (props) {
    var _a, _b;
    var operation = useOperation();
    var node = useCurrentNode();
    var selected = useSelected();
    var prefix = usePrefix('settings-form');
    var form = useMemo(function () {
        return createForm({
            values: node === null || node === void 0 ? void 0 : node.props,
            effects: function () {
                useLocales();
                useSnapshot(operation);
            },
        });
    }, [node, (_a = node === null || node === void 0 ? void 0 : node.designerProps) === null || _a === void 0 ? void 0 : _a.propsSchema, operation]);
    var isEmpty = !(node && ((_b = node.designerProps) === null || _b === void 0 ? void 0 : _b.propsSchema) &&
        selected.length === 1);
    var render = function () {
        if (!isEmpty) {
            return (React.createElement("div", { className: cls(prefix, props.className), style: props.style, key: node.id },
                React.createElement(SettingsFormContext.Provider, { value: props },
                    React.createElement(Form, { form: form, colon: false, labelWidth: 120, labelAlign: "left", wrapperAlign: "right", feedbackLayout: "none", tooltipLayout: "text" },
                        React.createElement(SchemaField, { schema: node.designerProps.propsSchema, components: props.components, scope: props.scope })))));
        }
        return (React.createElement("div", { className: prefix + '-empty' },
            React.createElement(Empty, null)));
    };
    return (React.createElement(IconWidget.Provider, { tooltip: true },
        React.createElement("div", { className: prefix + '-wrapper' },
            !isEmpty && React.createElement(NodePath, null),
            React.createElement("div", { className: prefix + '-content' }, render()))));
}, {
    scheduler: function (update) {
        cancelIdle(GlobalState.idleRequest);
        GlobalState.idleRequest = requestIdle(update);
    },
});
